;; Generated package description from dicom.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dicom" "1.4" "DICOM viewer - Digital Imaging & Communications in Medicine" '((emacs "29.1") (compat "31")) :commit "65998eca7a909e5560e6ce05eec33ee6a18e0d0c" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("multimedia" "hypermedia" "files") :url "https://github.com/minad/dicom")
